@@ -1,14 +1,15 @@
 # Created by julien piccini
 # email : piccini.julien@gmail.com
-# version : 0.0.3
+# version : 0.0.4
 
 
 import json as _json
 import time as _time
 from concurrent import futures as _futures
 from copy import deepcopy as _deepcopy
-from pathlib import _Path
-from typing import _Union, _IO
+from pathlib import Path as _Path
+from typing import Union as _Union
+from typing import IO as _IO
 import os
 
 # Non standard libraries
